@@ -13,7 +13,7 @@
 #include <KCalendarCore/FreeBusy>
 #include <KCalendarCore/Incidence>
 #include <KContacts/Addressee>
-#include <KIdentityManagement/Identity>
+#include <KIdentityManagementCore/Identity>
 #include <MessageComposer/ContactPreference>
 
 #include <gpgme++/context.h>
@@ -44,10 +44,9 @@ using ContactPreferences = QMap<QString, MessageComposer::ContactPreference>;
 
 using namespace Akonadi;
 
-Q_DECLARE_METATYPE(KIdentityManagement::Identity)
 Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
 Q_DECLARE_METATYPE(CryptoState)
-Q_DECLARE_METATYPE(QVector<ExpectedDialog>)
+Q_DECLARE_METATYPE(QList<ExpectedDialog>)
 Q_DECLARE_METATYPE(ContactPreferences)
 
 class FakeMessageQueueJob : public Akonadi::MessageQueueJob
@@ -88,7 +87,7 @@ public:
     {
     }
 
-    static QVector<ExpectedDialog> expectedWarningTwoActionsCancelDialogs;
+    static QList<ExpectedDialog> expectedWarningTwoActionsCancelDialogs;
 
 protected:
     int warningTwoActionsCancel(const QString &text, const QString &title, const KGuiItem &, const KGuiItem &, const KGuiItem &) override
@@ -115,7 +114,7 @@ protected:
     }
 };
 
-QVector<ExpectedDialog> FakeITIPHandlerDialogDelegate::expectedWarningTwoActionsCancelDialogs;
+QList<ExpectedDialog> FakeITIPHandlerDialogDelegate::expectedWarningTwoActionsCancelDialogs;
 
 class FakeITIPHandlerComponentFactory : public ITIPHandlerComponentFactory
 {
@@ -125,8 +124,9 @@ public:
     {
     }
 
-    Akonadi::MessageQueueJob *
-    createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) override
+    Akonadi::MessageQueueJob *createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                                                    const KIdentityManagementCore::Identity &identity,
+                                                    QObject *parent = nullptr) override
     {
         Q_UNUSED(incidence)
         Q_UNUSED(identity)
@@ -212,7 +212,7 @@ private Q_SLOTS:
     void testMailAttendees_data()
     {
         QTest::addColumn<KCalendarCore::Incidence::Ptr>("incidence");
-        QTest::addColumn<KIdentityManagement::Identity>("identity");
+        QTest::addColumn<KIdentityManagementCore::Identity>("identity");
         QTest::addColumn<bool>("bccMe");
         QTest::addColumn<QString>("attachment");
         QTest::addColumn<QString>("transport");
@@ -223,14 +223,14 @@ private Q_SLOTS:
         QTest::addColumn<QStringList>("expectedCcList");
         QTest::addColumn<QStringList>("expectedBccList");
         QTest::addColumn<CryptoState>("expectedCrypto");
-        QTest::addColumn<QVector<ExpectedDialog>>("expectedDialogs");
+        QTest::addColumn<QList<ExpectedDialog>>("expectedDialogs");
         QTest::addColumn<ContactPreferences>("contactPreferences");
 
         KCalendarCore::Incidence::Ptr incidence(new KCalendarCore::Event());
-        KIdentityManagement::Identity identity;
+        KIdentityManagementCore::Identity identity;
         identity.setPrimaryEmailAddress(s_ourEmail);
 
-        KIdentityManagement::Identity cryptoIdentity = identity;
+        KIdentityManagementCore::Identity cryptoIdentity = identity;
         cryptoIdentity.setPGPSigningKey(s_ourGpgKey);
         cryptoIdentity.setPGPEncryptionKey(s_ourGpgKey);
         cryptoIdentity.setPgpAutoSign(true);
@@ -249,7 +249,7 @@ private Q_SLOTS:
         QStringList toBccList;
         //----------------------------------------------------------------------------------------------
         QTest::newRow("No attendees") << incidence << identity << bccMe << attachment << transport << expectedResult << -1 << QString() << toList << toCcList
-                                      << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{} << ContactPreferences{};
+                                      << toBccList << CryptoState::Plain << QList<ExpectedDialog>{} << ContactPreferences{};
         //----------------------------------------------------------------------------------------------
         // One attendee, but without e-mail
         KCalendarCore::Attendee attendee(QStringLiteral("name1"), QString());
@@ -257,7 +257,7 @@ private Q_SLOTS:
         incidence->addAttendee(attendee);
         expectedResult = MailClient::ResultReallyNoAttendees;
         QTest::newRow("No attendees with email") << incidence << identity << bccMe << attachment << transport << expectedResult << -1 << QString() << toList
-                                                 << toCcList << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{} << ContactPreferences{};
+                                                 << toCcList << toBccList << CryptoState::Plain << QList<ExpectedDialog>{} << ContactPreferences{};
         //----------------------------------------------------------------------------------------------
         // One valid attendee
         attendee = KCalendarCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
@@ -267,7 +267,7 @@ private Q_SLOTS:
         expectedResult = MailClient::ResultSuccess;
         toList << QStringLiteral("test@foo.org");
         QTest::newRow("One attendee") << incidence << identity << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom
-                                      << toList << toCcList << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{} << ContactPreferences{};
+                                      << toList << toCcList << toBccList << CryptoState::Plain << QList<ExpectedDialog>{} << ContactPreferences{};
         //----------------------------------------------------------------------------------------------
         // One valid attendee
         attendee = KCalendarCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
@@ -278,7 +278,7 @@ private Q_SLOTS:
         expectedResult = MailClient::ResultSuccess;
         // Should default to the default transport
         QTest::newRow("Invalid transport") << incidence << identity << bccMe << attachment << invalidTransport << expectedResult << expectedTransportId
-                                           << expectedFrom << toList << toCcList << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{}
+                                           << expectedFrom << toList << toCcList << toBccList << CryptoState::Plain << QList<ExpectedDialog>{}
                                            << ContactPreferences{};
 
         //----------------------------------------------------------------------------------------------
@@ -290,7 +290,7 @@ private Q_SLOTS:
 
             QTest::newRow("One attendee, identity wants to sign")
                 << incidence << ident << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom << toList << toCcList
-                << toBccList << CryptoState::Signed << QVector<ExpectedDialog>{} << ContactPreferences{};
+                << toBccList << CryptoState::Signed << QList<ExpectedDialog>{} << ContactPreferences{};
         }
 
         //----------------------------------------------------------------------------------------------
@@ -303,7 +303,7 @@ private Q_SLOTS:
 
             QTest::newRow("One attendee, identity wants to encrypt")
                 << inc << cryptoIdentity << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom
-                << QStringList({s_testEmail}) << toCcList << toBccList << CryptoState::Encrypted << QVector<ExpectedDialog>{} << ContactPreferences{};
+                << QStringList({s_testEmail}) << toCcList << toBccList << CryptoState::Encrypted << QList<ExpectedDialog>{} << ContactPreferences{};
         }
 
         //----------------------------------------------------------------------------------------------
@@ -319,7 +319,7 @@ private Q_SLOTS:
 
             QTest::newRow("One attendee, attendee wants to encrypt")
                 << inc << ident << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom << QStringList({s_testEmail})
-                << toCcList << toBccList << CryptoState::Encrypted << QVector<ExpectedDialog>{}
+                << toCcList << toBccList << CryptoState::Encrypted << QList<ExpectedDialog>{}
                 << ContactPreferences{{s_testEmail, createPreference(s_testGpgKey, Kleo::AlwaysEncrypt, Kleo::AlwaysSign)}};
         }
 
@@ -336,8 +336,8 @@ private Q_SLOTS:
             QTest::newRow("Two attendees, one wants encryption, one has no key")
                 << inc << ident << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom
                 << QStringList({QStringLiteral("test@foo.org"), s_testEmail}) << toCcList << toBccList << CryptoState::Plain
-                << QVector<ExpectedDialog>{{QStringLiteral("conflicting encryption preferences"),
-                                            ITIPHandlerDialogDelegate::SecondaryAction /* do not encrypt */}}
+                << QList<ExpectedDialog>{{QStringLiteral("conflicting encryption preferences"),
+                                          ITIPHandlerDialogDelegate::SecondaryAction /* do not encrypt */}}
                 << ContactPreferences{{s_testEmail, createPreference(s_testGpgKey, Kleo::AlwaysEncrypt)}};
         }
 
@@ -355,7 +355,7 @@ private Q_SLOTS:
 
             QTest::newRow("Two attendees, both have keys but only one explicitly wants encryption")
                 << inc << ident << bccMe << attachment << transport << expectedResult << expectedTransportId << expectedFrom
-                << QStringList({s_testEmail, s_test2Email}) << toCcList << toBccList << CryptoState::Encrypted << QVector<ExpectedDialog>{}
+                << QStringList({s_testEmail, s_test2Email}) << toCcList << toBccList << CryptoState::Encrypted << QList<ExpectedDialog>{}
                 << ContactPreferences{{s_test2Email, createPreference(s_test2GpgKey, Kleo::AlwaysEncrypt)}};
         }
 
@@ -370,7 +370,7 @@ private Q_SLOTS:
         toBccList.clear();
         toBccList << s_ourEmail;
         QTest::newRow("Test bcc") << incidence << identity << /*bccMe*/ true << attachment << transport << expectedResult << expectedTransportId << expectedFrom
-                                  << toList << toCcList << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{} << ContactPreferences{};
+                                  << toList << toCcList << toBccList << CryptoState::Plain << QList<ExpectedDialog>{} << ContactPreferences{};
         //----------------------------------------------------------------------------------------------
         // Test CC list
         attendee = KCalendarCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
@@ -391,13 +391,13 @@ private Q_SLOTS:
         toCcList.clear();
         toCcList << QStringLiteral("optional@foo.org") << QStringLiteral("non@foo.org");
         QTest::newRow("Test cc") << incidence << identity << /*bccMe*/ true << attachment << transport << expectedResult << expectedTransportId << expectedFrom
-                                 << toList << toCcList << toBccList << CryptoState::Plain << QVector<ExpectedDialog>{} << ContactPreferences{};
+                                 << toList << toCcList << toBccList << CryptoState::Plain << QList<ExpectedDialog>{} << ContactPreferences{};
     }
 
     void testMailAttendees()
     {
         QFETCH(KCalendarCore::Incidence::Ptr, incidence);
-        QFETCH(KIdentityManagement::Identity, identity);
+        QFETCH(KIdentityManagementCore::Identity, identity);
         QFETCH(bool, bccMe);
         QFETCH(QString, attachment);
         QFETCH(QString, transport);
@@ -408,7 +408,7 @@ private Q_SLOTS:
         QFETCH(QStringList, expectedCcList);
         QFETCH(QStringList, expectedBccList);
         QFETCH(CryptoState, expectedCrypto);
-        QFETCH(QVector<ExpectedDialog>, expectedDialogs);
+        QFETCH(QList<ExpectedDialog>, expectedDialogs);
         QFETCH(ContactPreferences, contactPreferences);
 
         FakeMessageQueueJob::sUnitTestResults.clear();
@@ -417,7 +417,7 @@ private Q_SLOTS:
         TestableMailClient::preferences = contactPreferences;
 
         mPendingSignals = 1;
-        mMailClient->mailAttendees(incidence, identity, bccMe, attachment, transport);
+        mMailClient->mailAttendees(incidence, identity, KCalendarCore::iTIPRequest, bccMe, attachment, transport);
         waitForSignals();
 
         if (mLastResult != expectedResult) {
@@ -461,7 +461,7 @@ private Q_SLOTS:
     void testMailOrganizer_data()
     {
         QTest::addColumn<KCalendarCore::IncidenceBase::Ptr>("incidence");
-        QTest::addColumn<KIdentityManagement::Identity>("identity");
+        QTest::addColumn<KIdentityManagementCore::Identity>("identity");
         QTest::addColumn<QString>("from");
         QTest::addColumn<bool>("bccMe");
         QTest::addColumn<QString>("attachment");
@@ -475,7 +475,7 @@ private Q_SLOTS:
         QTest::addColumn<QString>("expectedSubject");
 
         KCalendarCore::IncidenceBase::Ptr incidence(new KCalendarCore::Event());
-        KIdentityManagement::Identity identity;
+        KIdentityManagementCore::Identity identity;
         const QString from = s_ourEmail;
         bool bccMe = false;
         QString attachment;
@@ -506,7 +506,7 @@ private Q_SLOTS:
     void testMailOrganizer()
     {
         QFETCH(KCalendarCore::IncidenceBase::Ptr, incidence);
-        QFETCH(KIdentityManagement::Identity, identity);
+        QFETCH(KIdentityManagementCore::Identity, identity);
         QFETCH(QString, from);
         QFETCH(bool, bccMe);
         QFETCH(QString, attachment);
@@ -521,7 +521,7 @@ private Q_SLOTS:
         FakeMessageQueueJob::sUnitTestResults.clear();
 
         mPendingSignals = 1;
-        mMailClient->mailOrganizer(incidence, identity, from, bccMe, attachment, subject, transport);
+        mMailClient->mailOrganizer(incidence, identity, from, KCalendarCore::iTIPReply, bccMe, attachment, subject, transport);
         waitForSignals();
         QCOMPARE(mLastResult, expectedResult);
 
@@ -539,7 +539,7 @@ private Q_SLOTS:
     void testMailTo_data()
     {
         QTest::addColumn<KCalendarCore::IncidenceBase::Ptr>("incidence");
-        QTest::addColumn<KIdentityManagement::Identity>("identity");
+        QTest::addColumn<KIdentityManagementCore::Identity>("identity");
         QTest::addColumn<QString>("from");
         QTest::addColumn<bool>("bccMe");
         QTest::addColumn<QString>("recipients");
@@ -552,7 +552,7 @@ private Q_SLOTS:
         QTest::addColumn<QStringList>("expectedBccList");
 
         KCalendarCore::IncidenceBase::Ptr incidence(new KCalendarCore::Event());
-        KIdentityManagement::Identity identity;
+        KIdentityManagementCore::Identity identity;
         const QString from = s_ourEmail;
         bool bccMe = false;
         const QString recipients = s_ourEmail;
@@ -573,7 +573,7 @@ private Q_SLOTS:
     void testMailTo()
     {
         QFETCH(KCalendarCore::IncidenceBase::Ptr, incidence);
-        QFETCH(KIdentityManagement::Identity, identity);
+        QFETCH(KIdentityManagementCore::Identity, identity);
         QFETCH(QString, from);
         QFETCH(bool, bccMe);
         QFETCH(QString, recipients);
@@ -587,7 +587,7 @@ private Q_SLOTS:
         FakeMessageQueueJob::sUnitTestResults.clear();
 
         mPendingSignals = 1;
-        mMailClient->mailTo(incidence, identity, from, bccMe, recipients, attachment, transport);
+        mMailClient->mailTo(incidence, identity, from, KCalendarCore::iTIPRequest, bccMe, recipients, attachment, transport);
         waitForSignals();
         QCOMPARE(mLastResult, expectedResult);
         UnitTestResult unitTestResult = FakeMessageQueueJob::sUnitTestResults.first();
