@@ -14,6 +14,7 @@
 
 #include <KCalendarCore/Incidence>
 
+#include <QFlags>
 #include <QWidget>
 
 #include <memory>
@@ -46,8 +47,8 @@ class IncidenceChangerPrivate;
  *          SLOT(slotCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
  *
  * connect( changer,
- *          SIGNAL(deleteFinished(int,QVector<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)),
- *          SLOT(slotDeleteFinished(int,QVector<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)) );
+ *          SIGNAL(deleteFinished(int,QList<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)),
+ *          SLOT(slotDeleteFinished(int,QList<Akonadi::Item::Id>,Akonadi::IncidenceChanger::ResultCode,QString)) );
  *
  * connect( changer,SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
  *          SLOT(slotModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)) );
@@ -116,6 +117,16 @@ public:
         InvitationPolicyDontSend ///< E-mails aren't sent
     };
 
+    /**
+     * Flags describing whether invitation emails should signed and/or encrypted.
+     */
+    enum InvitationPrivacy {
+        InvitationPrivacyPlain = 0, ///< Invitation emails are not signed or encrpyted
+        InvitationPrivacySign = 1, ///< Invitation emails are signed
+        InvitationPrivacyEncrypt = 2 //< Invitation emails are encrypted
+    };
+    Q_DECLARE_FLAGS(InvitationPrivacyFlags, InvitationPrivacy)
+
     /**
      * This enum describes change types.
      */
@@ -161,23 +172,24 @@ public:
      *         Returns -1 if @p incidence is invalid. The createFinished() signal
      *         won't be emitted in this case.
      */
-    int createIncidence(const KCalendarCore::Incidence::Ptr &incidence, const Akonadi::Collection &collection = Akonadi::Collection(), QWidget *parent = nullptr);
+    int
+    createIncidence(const KCalendarCore::Incidence::Ptr &incidence, const Akonadi::Collection &collection = Akonadi::Collection(), QWidget *parent = nullptr);
 
     /**
-      * Creates a new incidence.
-      *
-      * @param item Item containing the incidence to create and metadata, such as tags.
-      * @param collection Collection where the incidence will be created. If invalid, one according
-      *                   to the DestinationPolicy will be used. You can know which collection was
-      *                   used by calling lastCollectionUsed();
-      * @param parent widget parent to be used in dialogs.
-      *
-      * @return Returns an integer which identifies this change. This identifier is useful
-      *         to correlate this operation with the IncidenceChanger::createFinished() signal.
-      *
-      *         Returns -1 if @p item is invalid. The createFinished() signal
-      *         won't be emitted in this case.
-      */
+     * Creates a new incidence.
+     *
+     * @param item Item containing the incidence to create and metadata, such as tags.
+     * @param collection Collection where the incidence will be created. If invalid, one according
+     *                   to the DestinationPolicy will be used. You can know which collection was
+     *                   used by calling lastCollectionUsed();
+     * @param parent widget parent to be used in dialogs.
+     *
+     * @return Returns an integer which identifies this change. This identifier is useful
+     *         to correlate this operation with the IncidenceChanger::createFinished() signal.
+     *
+     *         Returns -1 if @p item is invalid. The createFinished() signal
+     *         won't be emitted in this case.
+     */
     int createFromItem(const Akonadi::Item &item, const Akonadi::Collection &collection = Akonadi::Collection(), QWidget *parent = nullptr);
 
     /**
@@ -223,8 +235,8 @@ public:
      *         won't be emitted in this case.
      */
     int modifyIncidence(const Akonadi::Item &item,
-                                          const KCalendarCore::Incidence::Ptr &originalPayload = KCalendarCore::Incidence::Ptr(),
-                                          QWidget *parent = nullptr);
+                        const KCalendarCore::Incidence::Ptr &originalPayload = KCalendarCore::Incidence::Ptr(),
+                        QWidget *parent = nullptr);
 
     /**
      * Some incidence operations require more than one change. Like dissociating
@@ -279,7 +291,7 @@ public:
      * @see setDefaultCollection()
      * @see DestinationPolicy
      */
-    Q_REQUIRED_RESULT Akonadi::Collection defaultCollection() const;
+    [[nodiscard]] Akonadi::Collection defaultCollection() const;
 
     /**
      * Sets the destination policy to use. The destination policy determines the
@@ -296,7 +308,7 @@ public:
      * @see setDestinationPolicy()
      * @see DestinationPolicy
      */
-    Q_REQUIRED_RESULT DestinationPolicy destinationPolicy() const;
+    [[nodiscard]] DestinationPolicy destinationPolicy() const;
 
     /**
      * Sets if IncidenceChanger should show error dialogs.
@@ -309,7 +321,7 @@ public:
      *
      * @see setShowDialogsOnError()
      */
-    Q_REQUIRED_RESULT bool showDialogsOnError() const;
+    [[nodiscard]] bool showDialogsOnError() const;
 
     /**
      * Sets if IncidenceChanger should honour collection's ACLs by disallowing changes if
@@ -325,7 +337,7 @@ public:
      * @see setRespectsCollectionRights()
      * @see ResultCode::ResultCodePermissions
      */
-    Q_REQUIRED_RESULT bool respectsCollectionRights() const;
+    [[nodiscard]] bool respectsCollectionRights() const;
 
     /**
      * Enable or disable history.
@@ -343,7 +355,7 @@ public:
      * @see history()
      * @see historyEnabled()
      */
-    Q_REQUIRED_RESULT bool historyEnabled() const;
+    [[nodiscard]] bool historyEnabled() const;
 
     /**
      * Returns a pointer to the history object.
@@ -363,7 +375,7 @@ public:
      *
      * @return true if the item was deleted recently, false otherwise.
      */
-    Q_REQUIRED_RESULT bool deletedRecently(Akonadi::Item::Id) const;
+    [[nodiscard]] bool deletedRecently(Akonadi::Item::Id) const;
 
     /**
      * Enables or disabled groupware communication.
@@ -377,7 +389,7 @@ public:
      * Default is false.
      * @see setGroupwareCommuniation()
      */
-    Q_REQUIRED_RESULT bool groupwareCommunication() const;
+    [[nodiscard]] bool groupwareCommunication() const;
 
     /**
      * Makes modifyIncidence() adjust recurrence parameters when modifying DTSTART.
@@ -388,7 +400,7 @@ public:
      * True if recurrence parameters are adjusted when modifying DTSTART.
      * Default is true.
      */
-    Q_REQUIRED_RESULT bool autoAdjustRecurrence() const;
+    [[nodiscard]] bool autoAdjustRecurrence() const;
 
     /**
      * Sets the invitation policy.
@@ -403,7 +415,7 @@ public:
      *
      * @since 4.12
      */
-    Q_REQUIRED_RESULT InvitationPolicy invitationPolicy() const;
+    [[nodiscard]] InvitationPolicy invitationPolicy() const;
 
     /**
      * Returns the collection that the last createIncidence() used.
@@ -411,7 +423,18 @@ public:
      *
      * @see createIncidence().
      */
-    Q_REQUIRED_RESULT Akonadi::Collection lastCollectionUsed() const;
+    [[nodiscard]] Akonadi::Collection lastCollectionUsed() const;
+
+    /**
+     * Sets the invitation privacy flags.
+     */
+    void setInvitationPrivacy(InvitationPrivacyFlags invitationPrivacy);
+
+    /**
+     * Returns the invitation privacy policy.
+     * Default value is InvitationPrivacyPlain.
+     */
+    [[nodiscard]] InvitationPrivacyFlags invitationPrivacy() const;
 
 Q_SIGNALS:
     /**
@@ -444,8 +467,7 @@ Q_SIGNALS:
      * @param errorString if @p resultCode is not ResultCodeSuccess, contains an i18n'ed error
      *        message. If you enabled error dialogs, this string was already presented to the user.
      */
-    void
-    deleteFinished(int changeId, const QVector<Akonadi::Item::Id> &itemIdList, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+    void deleteFinished(int changeId, const QList<Akonadi::Item::Id> &itemIdList, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
 private:
     //@cond PRIVATE
@@ -459,7 +481,8 @@ private:
 };
 }
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Akonadi::IncidenceChanger::InvitationPrivacyFlags)
+
 Q_DECLARE_METATYPE(Akonadi::IncidenceChanger::DestinationPolicy)
 Q_DECLARE_METATYPE(Akonadi::IncidenceChanger::ResultCode)
 Q_DECLARE_METATYPE(Akonadi::IncidenceChanger::ChangeType)
-
